#!/bin/sh

ZIP_PATH=`pwd`/Data.zip
if [ ! -f ${ZIP_PATH} ]
then
   {
      echo "Please run install.sh from the directory where you downloaded the fixpack to. "
      echo "Current directory is " `pwd`
      exit 1
   }
fi
#

if [ "${1}" = "-h" ]
then
{
        #
        echo "Usage: To run the silent install, please run install.sh with 3 parameters in this order:"
        echo "       install.sh WAS DOC_ROOT JAVA_HOME"
        echo "   Note: WAS could equal /usr/WebSphere/AppServer,"
        echo "         DOC_ROOT could equal /usr/HTTPServer/htdocs,"
        echo "         JAVA_HOME could equal /usr/java1.1"
        echo "                                         "
        echo "   install.sh may also be run without any parameters. "
        echo "   The user will be prompted for any of the 3 values above that are not set."
        echo "                                         "
        exit 0
}
elif [ "${1}" = "-help" ]
then
{
        #
        echo "Usage: To run the silent install, please run install.sh with 3 parameters in this order:"
        echo "       install.sh WAS DOC_ROOT JAVA_HOME"
        echo "   Note: WAS could equal /usr/WebSphere/AppServer,"
        echo "         DOC_ROOT could equal /usr/HTTPServer/htdocs,"
        echo "         JAVA_HOME could equal /usr/java1.1"
        echo "                                         "
        echo "   install.sh may also be run without any parameters. "
        echo "   The user will be prompted for any of the 3 values above that are not set."
        echo "                                         "
        exit 0
}
fi  

# See if doing silent install.
if [ "$#" != "0" ]
then
{ 
   if [ "$#" != "3" ]
   then
   {
      echo "Usage: To run the silent install, please run install.sh with 3 parameters in this order:"
      echo "       install.sh WAS DOC_ROOT JAVA_HOME"
      echo "   Note: WAS could equal /usr/WebSphere/AppServer,"
      echo "         DOC_ROOT could equal /usr/HTTPServer/htdocs,"
      echo "         JAVA_HOME could equal /usr/java1.1"
      echo "                                         "
      exit 
   }
   else
   {
      WAS=$1
      DOC_ROOT=$2
      JAVA_HOME=$3
   }
   fi
}
fi

while :
do
{
   if [ "${WAS}" = "" ]
   then
   {
      echo "Please enter the product root directory"
      read WAS
      continue
   }
   fi
      
   if [ ! -d ${WAS}   -o   ! -f ${WAS}/properties/com/ibm/websphere/product.properties  ]
   then
   {
      echo
      echo "Unable to locate file: ${WAS}/properties/com/ibm/websphere/product.properties"
      echo "Please re-enter the product root directory"
      read WAS
      echo 
      continue
   }
   fi
   echo "WAS is set to $WAS"

   break
}
done


while :
do
{
   if test "${DOC_ROOT}" =  ""
   then
   {
      echo "Please enter your document root path for your web server for samples update."
      echo "Example: /usr/HTTPServer/htdocs"
      read DOC_ROOT
      continue
   }
   fi

   if [ -d $DOC_ROOT ]
   then
   {
      echo "DOC_ROOT is set to $DOC_ROOT"
      break
   }
   else
   {
      echo
      echo
      echo "SORRY! That appears to be an invalid document directory for your web server."
      echo "Please re-enter your document directory."
      echo "Example: /usr/HTTPServer/htdocs"
      read DOC_ROOT
      continue
   } #if DOC_ROOT directory found
   fi

} #while do
done


while :
do
{
   if [ "${JAVA_HOME}" = "" ]
   then
   {
      echo "Please enter the Java Home directory"
      read JAVA_HOME 
      continue
   }
   fi

   if [ ! -d ${JAVA_HOME}   -o   ! -f ${JAVA_HOME}/bin/java  ]
   then
   {
      echo
      echo "Unable to locate file: ${JAVA_HOME}/bin/java"
      echo "Please re-enter the Java Home directory."
      read JAVA_HOME 
      echo
      continue
   }
   fi
   echo "JAVA_HOME is set to $JAVA_HOME" 

   break
}
done


#
CLASSPATH=`pwd`/Fixpack.class:`pwd`/fixpack.jar:`pwd`/install.jar:$JAVA_HOME/lib/classes.zip:.:$CLASSPATH
export CLASSPATH
PATH=$JAVA_HOME/bin:$PATH
export PATH
#

ulimit_n=1024
ulimit_p=`ulimit -n`
if test $ulimit_n -gt $ulimit_p
then
     echo "MSG:      Increasing ulimit to $ulimit_n"
     ulimit -n $ulimit_n
fi

# Put in to update WebSphere samples in the document root directory.
if [ ! -d $DOC_ROOT/WebSphereSamples ]
then
{
   mkdir $DOC_ROOT/WebSphereSamples
   chmod 755 $DOC_ROOT/WebSphereSamples
}
fi

if [ ! -d $DOC_ROOT/theme ]
then
{
   mkdir $DOC_ROOT/theme
   chmod 755 $DOC_ROOT/theme
}
fi

if [ ! -d $WAS/WebSphereSamples/SiteOutliner ]
then
{
   mkdir $WAS/WebSphereSamples/SiteOutliner
   chmod 755 $WAS/WebSphereSamples/SiteOutliner
}
fi


java -classpath $CLASSPATH Fixpack -install -b ${WAS} -f ${ZIP_PATH}


cp -r $WAS/WebSphereSamples/* $DOC_ROOT/WebSphereSamples
cp -r $WAS/theme/* $DOC_ROOT/theme
chmod 755 $WAS/bin/*

if [ -d $DOC_ROOT/en_US/WebSphereSamples ]
then
{
   cp -r $WAS/WebSphereSamples/* $DOC_ROOT/en_US/WebSphereSamples
}
fi

if [ -f $WAS/juninst ]
then
{
   chmod 744 $WAS/juninst
}
fi

if [ -f $WAS/hosts/default_host/default_app/servlets/runTransferApp.sh ]
then
{
   chmod 777 $WAS/hosts/default_host/default_app/servlets/runTransferApp.sh
}
fi



if test $ulimit_n -gt $ulimit_p
then
     ulimit -n $ulimit_p
fi


echo ""
exit 0
